[pisa-src] r1451 - trunk/pisacd/cdpending.c

  • From: Thomas Jansen <mithi@xxxxxxxxx>
  • To: pisa-src@xxxxxxxxxxxxx
  • Date: Fri, 30 Oct 2009 12:03:38 +0100

Author: tjansen
Date: Fri Oct 30 12:03:38 2009
New Revision: 1451

Log:
Fix -Wshadow warning:

cdpending.c: In function ‘pisa_pending_add’:
cdpending.c:68: warning: declaration of ‘send’ shadows a global declaration
/usr/include/sys/socket.h:141: warning: shadowed declaration is here

Modified:
   trunk/pisacd/cdpending.c

Modified: trunk/pisacd/cdpending.c
==============================================================================
--- trunk/pisacd/cdpending.c    Fri Oct 30 12:01:38 2009        (r1450)
+++ trunk/pisacd/cdpending.c    Fri Oct 30 12:03:38 2009        (r1451)
@@ -61,11 +61,11 @@
  * Create or find a pending request for a given HIT/type combination.
  * @param addr destination of the pending request
  * @param type pending packet type
  * @param send callback function to send the pending request
  * @param fail callback function called after reaching the maximum retries
  * @return pointer to the pending entry
  */
-pisa_pending *pisa_pending_add(pisa_conmgr_entry *entry, int type, 
pisa_pending_func send, pisa_pending_func fail)
+pisa_pending *pisa_pending_add(pisa_conmgr_entry *entry, int type, 
pisa_pending_func send_cb, pisa_pending_func fail_cb)
 {
        pisa_pending *pend = pisa_pending_find(entry, type);
 
@@ -79,8 +79,8 @@
        if (pend->data)
                free(pend->data);
        pend->data = NULL;
-       pend->send = send;
-       pend->fail = fail;
+       pend->send = send_cb;
+       pend->fail = fail_cb;
 
        cd_ctx.flag_pending = 1;
 
@@ -61,11 +61,11 @@
  * @param addr destination of the pending request
  * @param type pending packet type
- * @param send callback function to send the pending request
- * @param fail callback function called after reaching the maximum retries
+ * @param send_cb callback function to send the pending request
+ * @param fail_cb callback function called after reaching the maximum retries
  * @return pointer to the pending entry
  */

Other related posts:

  • » [pisa-src] r1451 - trunk/pisacd/cdpending.c - Thomas Jansen